Index

Struct Index 

pub struct Index {}

Implementations

Source

impl Index

pub fn new() -> Index

Creates a new dynamic index label, where the size of the index is not known at compile time, and is instead determined at runtime, typically from reading a file containing a representation of a tensor

pub fn with_value(_value: usize) -> Index

Creates a new static index label, where the size of the index is known at compile time