pub struct Index {}Implementations
Sourceimpl Index
impl Index
Sourcepub fn new() -> Index
pub fn new() -> Index
Creates a new dynamic index label, where the size of the index is not known at compile time, and is instead determined at runtime, typically from reading a file containing a representation of a tensor
Sourcepub fn with_value(_value: usize) -> Index
pub fn with_value(_value: usize) -> Index
Creates a new static index label, where the size of the index is known at compile time